==> nextcloud-app-deck-1%3A1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_419.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "%s on %s" : "%s en %s",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "Done" : "Terminado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Add card" : "Agregar tarjeta",
    "Filter by tag" : "Filtrar por etiqueta",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Remove due date" : "Eliminar fecha de expiración",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar el tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Archive board" : "Archivar tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Borrar tableros",
    "Share" : "Compartir",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_419.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "%s on %s" : "%s en %s",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "Done" : "Terminado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "File already exists" : "El archivo ya existe",
    "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
    "Add card" : "Agregar tarjeta",
    "Filter by tag" : "Filtrar por etiqueta",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Borrar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Remove due date" : "Eliminar fecha de expiración",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "hace segundos",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar el tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Archive board" : "Archivar tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Borrar tableros",
    "Share" : "Compartir",
    "This week" : "Esta semana"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
